==> apache-beam-2.5.0-source-release.zip: beam-release-2.5.0/runners/spark/src/main/java/org/apache/beam/runners/spark/metrics/MetricsAccumulatorParam.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.beam.runners.spark.metrics;

import org.apache.beam.runners.core.metrics.MetricsContainerStepMap;
import org.apache.spark.AccumulatorParam;


/**
 * Metrics accumulator param.
 */
class MetricsAccumulatorParam implements AccumulatorParam<MetricsContainerStepMap> {
  @Override
  public MetricsContainerStepMap addAccumulator(
      MetricsContainerStepMap c1,
      MetricsContainerStepMap c2) {
    return addInPlace(c1, c2);
  }

  @Override
  public MetricsContainerStepMap addInPlace(
      MetricsContainerStepMap c1,
      MetricsContainerStepMap c2) {
    c1.updateAll(c2);
    return c1;
  }

  @Override
  public MetricsContainerStepMap zero(MetricsContainerStepMap initialValue) {
    return new MetricsContainerStepMap();
  }
}

==> apache-beam-2.8.0-source-release.zip: beam-release-2.8.0/runners/spark/src/main/java/org/apache/beam/runners/spark/metrics/MetricsAccumulatorParam.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.beam.runners.spark.metrics;

import org.apache.beam.runners.core.metrics.MetricsContainerStepMap;
import org.apache.spark.AccumulatorParam;

/** Metrics accumulator param. */
class MetricsAccumulatorParam implements AccumulatorParam<MetricsContainerStepMap> {
  @Override
  public MetricsContainerStepMap addAccumulator(
      MetricsContainerStepMap c1, MetricsContainerStepMap c2) {
    return addInPlace(c1, c2);
  }

  @Override
  public MetricsContainerStepMap addInPlace(
      MetricsContainerStepMap c1, MetricsContainerStepMap c2) {
    c1.updateAll(c2);
    return c1;
  }

  @Override
  public MetricsContainerStepMap zero(MetricsContainerStepMap initialValue) {
    return new MetricsContainerStepMap();
  }
}
